Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(667)

Unified Diff: tests/language_2/unresolved_in_factory_test.dart

Issue 3008723002: Migrate block 163 to Dart 2.0. (Closed)
Patch Set: Merge fixups Created 3 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: tests/language_2/unresolved_in_factory_test.dart
diff --git a/tests/language/unresolved_in_factory_negative_test.dart b/tests/language_2/unresolved_in_factory_test.dart
similarity index 70%
rename from tests/language/unresolved_in_factory_negative_test.dart
rename to tests/language_2/unresolved_in_factory_test.dart
index 8166ac8f510bf5356ed452ec5ea23d2879116826..a9aa72abc720afdd89968eb51f9f6b6d46167c62 100644
--- a/tests/language/unresolved_in_factory_negative_test.dart
+++ b/tests/language_2/unresolved_in_factory_test.dart
@@ -2,12 +2,11 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.
// Test that an unresolved method call in a factory is a resolution
// error.
class A {
factory A() {
- foo();
+ foo(); /*@compile-error=unspecified*/
}
}
« no previous file with comments | « tests/language_2/unresolved_default_constructor_test.dart ('k') | tests/language_2/unresolved_top_level_method_test.dart » ('j') | no next file with comments »
@@ -2,12 +2,11 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.
-// Test that an unresolved method call in a factory is a resolution
-// error.
+// Test that an unresolved method call in a factory is a compile error.
class A {
factory A() {

Powered by Google App Engine
This is Rietveld 408576698